@@ -4,6 +4,11 @@ use Mojo::Base 'Mojolicious::Controller';
 our $RES  = {};
 our $CODE = 200;
 
+sub test_file {
+  my ($c, $args, $cb) = @_;
+  $c->$cb('dummy data');
+}
+
 sub boolean_in_url {
   my ($c, $args, $cb) = @_;
   $c->$cb({p1 => $args->{p1}, q1 => $args->{q1}});
